@@ -14,11 +14,10 @@
 
 import time
 from collections.abc import Awaitable, Callable
-from typing import Sequence
 
 import structlog
 from asgi_correlation_id.context import correlation_id
-from beartype.typing import cast
+from beartype.typing import Sequence, cast
 from fastapi import FastAPI, Request, Response
 from uvicorn._types import HTTPScope
 from uvicorn.protocols.utils import get_path_with_query_string
@@ -38,12 +37,7 @@ def add_timing_middleware(app: FastAPI, debug_endpoints: Sequence[str] | None =
         structlog.contextvars.bind_contextvars(request_id=request_id)
 
         start_time = time.perf_counter_ns()
-        response = Response(status_code=500)
-        try:
-            response = await call_next(request)
-        except Exception:
-            structlog.get_logger("api.error").exception("Uncaught exception")
-            raise
+        response = await call_next(request)
         process_time = time.perf_counter_ns() - start_time
         duration_ms = process_time / 1_000_000  # Convert nanoseconds to milliseconds
         url: str = get_path_with_query_string(cast(HTTPScope, request.scope))
